==> angular-stockcharts-1.0.3.tgz: package/README.md <==
<div align="center">
	<a href="https://www.npmjs.com/~canvasjs">
		<img src="https://canvasjs.com/wp-content/uploads/images/logo/canvasjs-logo-240x100.png" alt="CanvasJS"/>
	</a>
</div>

# CanvasJS Angular StockCharts
CanvasJS Angular StockChart Component for creating interactive stockchart for your web pages. Library supports a wide range of chart types including line, area, column, candlestick, etc.

<br/>

<a href="https://canvasjs.com/angular-charts/#stockcharts">
	<img src="https://canvasjs.com/wp-content/uploads/images/npm/angular/angular-stockcharts.jpg" alt="CanvasJS Angular StockCharts">
</a>

<br/>

## Links
- [Official Website](https://canvasjs.com/)
- [Angular StockCharts Demo](https://canvasjs.com/angular-charts/#stockcharts)
- [Download CanvasJS](https://canvasjs.com/download-html5-charting-graphing-library/)
- [Angular StockChart Integration](https://canvasjs.com/docs/stockcharts/integration/angular/)
- [StockChart Documentation](https://canvasjs.com/docs/stockcharts/basics-of-creating-html5-stockchart/)
- [StockChart Support Forum](https://canvasjs.com/forums/forum/stockchart-support/)

<br/>

## Installing CanvasJS Angular StockCharts
Install CanvasJS StockCharts package to your Angular app
##### Install Angular StockChart via NPM
```
npm install @canvasjs/angular-stockcharts
```
See [npm documentation](https://docs.npmjs.com/) to know more about npm usage.

##### Import StockChart Component & register the module
Import the StockChart module into your Angular application (app.module.ts) & register it.
```
import { NgModule } from '@angular/core';
import { BrowserModule } from '@angular/platform-browser';

import { AppComponent } from './app.component';

import { CanvasJSAngularStockChartsModule } from '@canvasjs/angular-stockcharts';

@NgModule({
  declarations: [
	AppComponent
  ],
  imports: [
	BrowserModule,
	CanvasJSAngularStockChartsModule
  ],
  providers: [],
  bootstrap: [AppComponent]
})
export class AppModule { }
```

##### Set the stockchart-options & create stockchart
Set the stockchart-options in app.component.ts & use ‘canvasjs-stockchart’ selector in app.component.html to create stockchart.
```
//app.component.ts
import { Component } from '@angular/core';

@Component({
  selector: 'app-root',
  templateUrl: './app.component.html',
  styleUrls: ['./app.component.css']
})
    
export class AppComponent {
  stockChartOptions = {
    title: {
      text: "CanvasJS Angular StockChart"
    },
    theme: "light2",
    charts: [{
      data: [{
        type: "line",
        dataPoints: [
          { x: new Date("2018-01-01"), y: 71 },
          { x: new Date("2018-02-01"), y: 55 },
          { x: new Date("2018-03-01"), y: 50 },
          { x: new Date("2018-04-01"), y: 65 },
          { x: new Date("2018-05-01"), y: 95 },
          { x: new Date("2018-06-01"), y: 68 },
          { x: new Date("2018-07-01"), y: 28 },
          { x: new Date("2018-08-01"), y: 34 },
          { x: new Date("2018-09-01"), y: 14 },
          { x: new Date("2018-10-01"), y: 71 },
          { x: new Date("2018-11-01"), y: 55 },
          { x: new Date("2018-12-01"), y: 50 },
          { x: new Date("2019-01-01"), y: 34 },
          { x: new Date("2019-02-01"), y: 50 },
          { x: new Date("2019-03-01"), y: 50 },
          { x: new Date("2019-04-01"), y: 95 },
          { x: new Date("2019-05-01"), y: 68 },
          { x: new Date("2019-06-01"), y: 28 },
          { x: new Date("2019-07-01"), y: 34 },
          { x: new Date("2019-08-01"), y: 65 },
          { x: new Date("2019-09-01"), y: 55 },
          { x: new Date("2019-10-01"), y: 71 },
          { x: new Date("2019-11-01"), y: 55 },
          { x: new Date("2019-12-01"), y: 50 }
        ]
      }]
    }],
    navigator: {
      slider: {
        minimum: new Date("2018-07-01"),
        maximum: new Date("2019-06-30")
      }
    }
  }
}
    
//app.component.html
<div>
   <canvasjs-stockchart [options]="stockChartOptions"></canvasjs-stockchart>
</div>
```

<br/>

<img src="https://canvasjs.com/wp-content/uploads/images/npm/angular/angular-stockchart.png" alt="Angular StockChart">

<br/>

#### Interactive Angular StockCharts
![Angular Interactive StockCharts](https://canvasjs.com/wp-content/uploads/images/npm/angular/angular-stockchart-multiple-charts.gif)

==> angular-stockcharts-1.1.0.tgz: package/README.md <==
<div align="center">
    <a href="https://www.npmjs.com/~canvasjs">
        <img src="https://canvasjs.com/wp-content/uploads/images/logo/canvasjs-logo-240x100.png" alt="CanvasJS"/>
    </a>
</div>

# CanvasJS Angular StockCharts
CanvasJS Angular StockChart Component for creating interactive stockchart for your web pages. Library supports a wide range of chart types including line, area, column, candlestick, etc.

<br/>

<a href="https://canvasjs.com/angular-charts/#stockcharts">
    <img src="https://canvasjs.com/wp-content/uploads/images/npm/angular/angular-stockcharts.jpg" alt="CanvasJS Angular StockCharts">
</a>

<br/>

## Links
- [Official Website](https://canvasjs.com/)
- [Angular StockCharts Demo](https://canvasjs.com/angular-charts/#stockcharts)
- [Download CanvasJS](https://canvasjs.com/download-html5-charting-graphing-library/)
- [Angular StockChart Integration](https://canvasjs.com/docs/stockcharts/integration/angular/)
- [StockChart Documentation](https://canvasjs.com/docs/stockcharts/basics-of-creating-html5-stockchart/)
- [StockChart Support Forum](https://canvasjs.com/forums/forum/stockchart-support/)

<br/>

## Installing CanvasJS Angular StockCharts
Install CanvasJS StockCharts package to your Angular app
##### Install Angular StockChart via NPM
```
npm install @canvasjs/angular-stockcharts
```
See [npm documentation](https://docs.npmjs.com/) to know more about npm usage.

##### Import StockChart Module & register it
Import the StockChart module into your Angular application (app.component.ts) & register it.
```
import { Component } from '@angular/core';
import { CommonModule } from '@angular/common';
import { RouterOutlet } from '@angular/router';
import { CanvasJSAngularStockChartsModule } from '@canvasjs/angular-stockcharts';

@Component({
  selector: 'app-root',
  standalone: true,
  imports: [
    CommonModule,
    RouterOutlet,
    CanvasJSAngularStockChartsModule,
  ],
  templateUrl: './app.component.html',
  styleUrl: './app.component.css',
})
export class AppComponent { }
```

##### Set the stockchart-options & create stockchart
Set the stockchart-options in app.component.ts & use ‘canvasjs-stockchart’ selector in app.component.html to create stockchart.
```
//app.component.ts
import { Component } from '@angular/core';
import { CommonModule } from '@angular/common';
import { RouterOutlet } from '@angular/router';
import { CanvasJSAngularStockChartsModule } from '@canvasjs/angular-stockcharts';

@Component({
  selector: 'app-root',
  standalone: true,
  imports: [
    CommonModule,
    RouterOutlet,
    CanvasJSAngularStockChartsModule,
  ],
  templateUrl: './app.component.html',
  styleUrl: './app.component.css',
})

export class AppComponent {
  stockChartOptions = {
    title: {
      text: "CanvasJS Angular StockChart"
    },
    theme: "light2",
    charts: [{
      data: [{
        type: "line",
        dataPoints: [
          { x: new Date("2018-01-01"), y: 71 },
          { x: new Date("2018-02-01"), y: 55 },
          { x: new Date("2018-03-01"), y: 50 },
          { x: new Date("2018-04-01"), y: 65 },
          { x: new Date("2018-05-01"), y: 95 },
          { x: new Date("2018-06-01"), y: 68 },
          { x: new Date("2018-07-01"), y: 28 },
          { x: new Date("2018-08-01"), y: 34 },
          { x: new Date("2018-09-01"), y: 14 },
          { x: new Date("2018-10-01"), y: 71 },
          { x: new Date("2018-11-01"), y: 55 },
          { x: new Date("2018-12-01"), y: 50 },
          { x: new Date("2019-01-01"), y: 34 },
          { x: new Date("2019-02-01"), y: 50 },
          { x: new Date("2019-03-01"), y: 50 },
          { x: new Date("2019-04-01"), y: 95 },
          { x: new Date("2019-05-01"), y: 68 },
          { x: new Date("2019-06-01"), y: 28 },
          { x: new Date("2019-07-01"), y: 34 },
          { x: new Date("2019-08-01"), y: 65 },
          { x: new Date("2019-09-01"), y: 55 },
          { x: new Date("2019-10-01"), y: 71 },
          { x: new Date("2019-11-01"), y: 55 },
          { x: new Date("2019-12-01"), y: 50 }
        ]
      }]
    }],
    navigator: {
      slider: {
        minimum: new Date("2018-07-01"),
        maximum: new Date("2019-06-30")
      }
    }
  }
}

//app.component.html
<div>
   <canvasjs-stockchart [options]="stockChartOptions"></canvasjs-stockchart>
</div>
```

<br/>

<img src="https://canvasjs.com/wp-content/uploads/images/npm/angular/angular-stockchart.png" alt="Angular StockChart">

<br/>

#### Interactive Angular StockCharts
![Angular Interactive StockCharts](https://canvasjs.com/wp-content/uploads/images/npm/angular/angular-stockchart-multiple-charts.gif)
